#!/usr/bin/env python
# -*- coding: ISO-8859-1 -*-

# Copyright (C) 2002, 2003 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses, os, os.path, sys
import helper
import config
import services.songdb
import services.player

##############################################################################
# gettext initialization.
##############################################################################

# We have to do this very early, before importing our modules. We
# assume that the locales lie in same dir as this module. This may not
# be the case, if the .mo files are installed at their proper
# location.

try:
    import gettext
    locallocaledir = os.path.join(os.path.dirname(sys.argv[0]), "../locale")
    gettext.install("PyTone", locallocaledir)
except:
    # Disable localization if there is any problem with the above.
    # This works around a problem with Python 2.1
    import __builtin__
    __builtin__.__dict__['_'] = lambda s: s


# Uncomment the next line, if you want to experience a little bit with
# the number of bytecode instructions after which a context switch
# occurs.

# import sys; sys.setcheckinterval(250)

# create .pytone dir in user home
try:
    os.mkdir(os.path.expanduser("~/.pytone"))
except OSError, e:
    if e.errno!=17:
        raise

##############################################################################
# start various services
##############################################################################

# song databases
songdbids = []
songdbid = services.songdb.initsongdb("main", config.database.main)
if songdbid:
    songdbids.append(songdbid)
songdbid = services.songdb.initsongdb("secondary", config.database.secondary)
if songdbid:
    songdbids.append(songdbid)

# one or two players
playerids = [services.player.initplayer("main", config.player.main),
             services.player.initplayer("secondary", config.player.secondary)]

##############################################################################
# setup main screen
##############################################################################

def main(stdscr):
    # we have to import the main screen here, because then we are
    # sure that the curses library is already initialized and therefore
    # colors work 
    import mainscreen
    m = mainscreen.mainscreen(stdscr, songdbids, playerids)
    try:
        m.run()
    except:
        m.dump()
        raise
    m.quit()

# fire up user interface
try:
    ms = curses.wrapper(main)
except:
    helper.print_exc_plus()
    raise
